@@ -2,7 +2,6 @@ app <- ShinyDriver$new("../", seed = 1)
 app$snapshotInit("basicRunSpot")
 
 app$setInputs(tabs = "spotConfig")
-app$setInputs(tabs = "runMode")
+try(app$setInputs(tabs = "runMode"), silent = T)
 app$setInputs(runSpotIter = "click")
-Sys.sleep(5)
 app$snapshot(list(output = "resultTable"))
