@@ -2,12 +2,11 @@ app <- ShinyDriver$new("../", seed = 1)
 app$snapshotInit("basicSpotThenDOEThenSPOT")
 
 app$setInputs(tabs = "spotConfig")
-app$setInputs(tabs = "runMode")
+try(app$setInputs(tabs = "runMode"), silent = T)
 app$setInputs(runSpotIter = "click")
 app$setInputs(tabs = "spotConfig")
-app$setInputs(tabs = "runMode")
+try(app$setInputs(tabs = "runMode"), silent = T)
 app$setInputs(runCreateDOE = "click")
 app$setInputs(evaluateData = "click")
 app$setInputs(runSpotIter = "click")
-Sys.sleep(2)
 app$snapshot(list(output = "resultTable"))
