@@ -18,7 +18,7 @@ app$setInputs(tabs = "spotConfig")
 app$setInputs(modelSelector = "buildRandomForest")
 app$setInputs(optimizerSelector = "optimLBFGSB")
 app$setInputs(designSelector = "designUniformRandom")
-app$setInputs(tabs = "runMode")
+try(app$setInputs(tabs = "runMode"), silent = T)
 app$setInputs(runSpotIter = "click")
 app$setInputs(runCreateDOE = "click")
 app$setInputs(proposeNewPoint = "click")
