@@ -6,7 +6,7 @@ app$setInputs(addDimension = "click")
 app$setInputs(lowerBound3 = -5)
 app$setInputs(upperBound3 = 5)
 app$setInputs(tabs = "spotConfig")
-app$setInputs(tabs = "runMode")
+try(app$setInputs(tabs = "runMode"), silent = T)
 app$setInputs(runCreateDOE = "click")
 app$setInputs(evaluateData = "click")
 app$snapshot(list(output = "resultTable"))
