@@ -10,13 +10,12 @@ app$setInputs(xml_optimGenoudcontrol = TRUE)
 app$setInputs(xml_optimGenoudcontrolpopulationSize = 40)
 app$setInputs(xml_optimGenoudcontrolfunEvals = 200)
 app$setInputs(modelSelector = "buildRandomForest")
-app$setInputs(tabs = "runMode")
-app$setInputs(runSpotIter = "click")
-app$setInputs(runCreateDOE = "click")
-app$setInputs(evaluateData = "click")
-app$setInputs(proposeNewPoint = "click")
-app$setInputs(evaluateData = "click")
-app$setInputs(selectorXAUTO = "X4")
-Sys.sleep(5)
+try(app$setInputs(tabs = "runMode"), silent = T)
+app$setInputs(runSpotIter = "click",wait_=FALSE, values_=FALSE)
+app$setInputs(runCreateDOE = "click",wait_=FALSE, values_=FALSE)
+app$setInputs(evaluateData = "click",wait_=FALSE, values_=FALSE)
+app$setInputs(proposeNewPoint = "click",wait_=FALSE, values_=FALSE)
+app$setInputs(evaluateData = "click",wait_=FALSE, values_=FALSE)
+app$setInputs(selectorXAUTO = "X4",wait_=FALSE, values_=FALSE)
 app$snapshot(list(output = "resultTable"))
 
