@@ -5,11 +5,10 @@ app$setInputs(objectiveFunction = "smoof")
 app$setInputs(smoofFunctionSelector = "Bird")
 app$setInputs(addDimension = "click")
 app$setInputs(tabs = "spotConfig")
-app$setInputs(tabs = "runMode")
-Sys.sleep(5)
+try(app$setInputs(tabs = "runMode"), silent = T)
 app$setInputs(runSpotIter = "click")
 app$setInputs(tabs = "objectiveFunction")
 app$setInputs(removeDimension6 = "click")
-app$setInputs(tabs = "runMode")
+try(app$setInputs(tabs = "runMode"), silent = T)
 app$setInputs(runSpotIter = "click")
 app$snapshot(list(output = "resultTable"))
