@@ -7,10 +7,10 @@ app$setInputs(tabs = "objectiveFunction")
 app$setInputs(tabs = "spotConfig")
 app$setInputs(xml_designLHDcontrol = TRUE)
 app$setInputs(xml_designLHDcontrolsize = "cflbre")
-app$setInputs(tabs = "runMode")
+try(app$setInputs(tabs = "runMode"), silent = T)
 app$setInputs(runCreateDOE = "click")
 app$setInputs(tabs = "spotConfig")
 app$setInputs(xml_designLHDcontrolsize = 10)
-app$setInputs(tabs = "runMode")
+try(app$setInputs(tabs = "runMode"), silent = T)
 app$setInputs(runCreateDOE = "click")
 app$snapshot(list(output = "resultTable"))
