@@ -6,16 +6,16 @@ app$setInputs(funName = "fakeFunctionForTesting")
 app$setInputs(addDimension = "click")
 app$setInputs(dimensionAmount2 = 2)
 app$setInputs(tabs = "spotConfig")
-app$setInputs(tabs = "runMode")
+try(app$setInputs(tabs = "runMode"), silent = T)
 app$setInputs(runCreateDOE = "click")
 app$setInputs(tabs = "objectiveFunction")
 app$setInputs(funName = "funBranin")
 app$setInputs(tabs = "spotConfig")
-app$setInputs(tabs = "runMode")
+try(app$setInputs(tabs = "runMode"), silent = T)
 app$setInputs(runCreateDOE = "click")
 app$setInputs(tabs = "objectiveFunction")
 app$setInputs(funName = "fakeFunctionForTesting")
-app$setInputs(tabs = "runMode")
+try(app$setInputs(tabs = "runMode"), silent = T)
 app$setInputs(evaluateData = "click")
 Sys.sleep(2)
 app$snapshot(list(output = "resultTable"))
