@@ -2,12 +2,12 @@ app <- ShinyDriver$new("../", seed = 1)
 app$snapshotInit("testWrongInputProposeNewPoint")
 
 app$setInputs(tabs = "spotConfig")
-app$setInputs(tabs = "runMode")
+try(app$setInputs(tabs = "runMode"), silent = T)
 app$setInputs(runCreateDOE = "click")
 app$setInputs(evaluateData = "click")
 app$setInputs(tabs = "spotConfig")
 app$setInputs(xml_optimLHDcontrol = TRUE)
 app$setInputs(xml_optimLHDcontrolfunEvals = "chara")
-app$setInputs(tabs = "runMode")
+try(app$setInputs(tabs = "runMode"), silent = T)
 app$setInputs(proposeNewPoint = "click")
 app$snapshot(list(output = "resultTable"))
